#!/usr/bin/env python3
# -*- coding:utf-8 -*-

"""
This module implements specialized utilities for CKIPNLP containers.
"""

__author__ = 'Mu Yang <http://muyang.pro>'
__copyright__ = '2018-2023 CKIP Lab'
__license__ = 'GPL-3.0'
